# tetris-pygame
[![PyPI version](https://badge.fury.io/py/tetris-pygame.svg)](https://pypi.org/project/tetris-pygame/)
This is a Python implementation of the classic game Tetris, built using the Pygame library. The game includes a leaderboard.


***install***

```bash
pip install tetris-pygame
```

***usage***

If you installed package with pip:
Run:
```bash
tetris
```
Reset leaderboard:
```bash
leaderboard
```
If you cloned the repository:
Install all requirements:
```bash
pip install -r requirements.txt
```
Run:
```bash
python -m tetris.main
```
